@@ -58,7 +58,7 @@ for(mlist in names(mats[-1])){
     for(ri in 1:size(',m,'setup)){ //for each row of matrix setup
       if(',m,'setup[ ri,5] > 0 && ( statei == 0 || statei == nlatent + ',m,'setup[ ri,5])){ // if individually varying
         s',m,'[',m,'setup[ ri,1], ',m,'setup[ri,2]] = 
-          ','tform(state[nlatent +',m,'setup[ri,5] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4] ); 
+          ','tform(state[nlatent +',m,'setup[ri,5] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4], ',m,'values[ri,6] ); 
       }
     }')
     })),collapse='\n'),'}',collapse='\n')
@@ -70,7 +70,7 @@ for(mlist in names(mats[-1])){
     for(ri in 1:size(',m,'setup)){
       if(',m,'setup[ ri,5] > 0){ 
          s',m,'[',m,'setup[ ri,1], ',m,'setup[ri,2]] = ',
-          'tform(state[nlatent +',m,'setup[ri,5] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4] ); 
+          'tform(state[nlatent +',m,'setup[ri,5] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4], ',m,'values[ri,6] ); 
       }
     }')
     })),collapse='\n'),'}',collapse='\n')
@@ -82,7 +82,8 @@ for(mlist in names(mats[-1])){
     for(ri in 1:size(',m,'setup)){
       if(',m,'setup[ ri,5] > 0){ 
          s',m,'[',m,'setup[ ri,1], ',m,'setup[ri,2]] = ',
-         'tform(ukfstates[nlatent +',m,'setup[ri,5], statei ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4] ); 
+         'tform(ukfstates[nlatent +',m,'setup[ri,5], statei ], ',m,'setup[ri,4], ',
+            m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4], ',m,'values[ri,6] ); 
       }
     }')
     })),collapse='\n'),'}',collapse='\n')
@@ -94,13 +95,17 @@ for(mlist in names(mats[-1])){
     for(ri in 1:size(',m,'setup)){
       if(',m,'setup[ ri,5] > 0){ 
          s',m,'[',m,'setup[ ri,1], ',m,'setup[ri,2]] = ',
-          'tform(state[nlatent +',m,'setup[ri,5] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4] ); 
+          'tform(state[nlatent +',m,'setup[ri,5] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4], ',m,'values[ri,6] ); 
       }
     }')
     })),collapse='\n'),'}',collapse='\n')
     
     #end intoverpop setup
     
+    
+    #adjust diffusion calcs to diffusionsqrt
+    ctstanmodel$calcs$dynamic <- gsub('sDIFFUSION','sDIFFUSIONsqrt',ctstanmodel$calcs$dynamic)
+    intoverpopdynamiccalcs <- gsub('sDIFFUSION','sDIFFUSIONsqrt',intoverpopdynamiccalcs)
 
 
 ukfilterfunc<-function(ppchecking){
@@ -134,14 +139,14 @@ ukfilterfunc<-function(ppchecking){
   if(savescores) kout = rep_array(rep_vector(99999,rows(kout[1])),ndatapoints);
 
   for(rowi in 1:ndatapoints){
-
     matrix[ukf ? nlatentpop : 0, ukffull ? 2*nlatentpop +2 : nlatentpop + 2 ] ukfstates; //sampled states relevant for dynamics
     matrix[ukf ? nmanifest : 0 , ukffull ? 2*nlatentpop +2 : nlatentpop + 2] ukfmeasures; // expected measures based on sampled states
     si=subject[rowi];
+
     
     if(T0check[rowi] == 1) { // calculate initial matrices if this is first row for si
-
-    ',subjectparscalc2(pop=FALSE,smats=TRUE),'
+  
+    ',subjectparscalc2(popmats=ifelse(gendata,FALSE,TRUE),subjmats=ifelse(gendata,FALSE,TRUE)),'
 
       if(ukf==1){
         eta = rep_vector(0,nlatentpop); // because some values stay zero
@@ -218,12 +223,14 @@ ukfilterfunc<-function(ppchecking){
               if(statei== 0) {
                 base = sDRIFT * state[1:nlatent] + sCINT[,1];
               }
-              if(statei > 0) J[1:nlatent,statei] = (( sDRIFT * state[1:nlatent] + sCINT[,1]) - base)/1e-6;
+              if(statei > 0) {
+                J[1:nlatent,statei] = (( sDRIFT * state[1:nlatent] + sCINT[,1]) - base)/1e-6;
+              }
             }
             ',paste0(ctstanmodel$calcs$dynamic,';\n',collapse=' '),' //find a way to remove this repeat
             Je= expm2(J * dTsmall[rowi]) ;
             discreteDRIFT = expm2(append_row(append_col(sDRIFT,sCINT),rep_vector(0,nlatent+1)\') * dTsmall[rowi]);
-            sasymDIFFUSION = to_matrix(  -kronsum(J[1:nlatent,1:nlatent]) \\ to_vector(tcrossprod(sDIFFUSION)), nlatent,nlatent);
+            sasymDIFFUSION = to_matrix(  -kronsum(J[1:nlatent,1:nlatent]) \\ to_vector(tcrossprod(sDIFFUSIONsqrt)), nlatent,nlatent);
             discreteDIFFUSION =  sasymDIFFUSION - quad_form( sasymDIFFUSION, Je[1:nlatent,1:nlatent]\' );
             etacov = quad_form(etacov, Je\');
             etacov[1:nlatent,1:nlatent] += discreteDIFFUSION;
@@ -232,26 +239,6 @@ ukfilterfunc<-function(ppchecking){
         }
 
         if(continuoustime==0){ //need covariance in here
-            for(statei in 0:nlatentpop){
-              if(statei>0){
-                J[statei,statei] = 1e-6;
-                state = eta + J[,statei];
-              } else {
-                state = eta;
-              }
-              ',paste0(ctstanmodel$calcs$dynamic,';\n',collapse=' '),';\n', intoverpopdynamiccalcs,' //remove diffusion calcs and do elsewhere
-              if(statei== 0) {
-                base = sDRIFT * state[1:nlatent] + sCINT[,1];
-              }
-              if(statei > 0) J[1:nlatent,statei] = (( sDRIFT * state[1:nlatent] + sCINT[,1]) - base)/1e-6;
-            }
-          ',paste0(ctstanmodel$calcs$dynamic,';\n',collapse=' '),'
-          discreteDRIFT=append_row(append_col(sDRIFT,sCINT),rep_matrix(0,1,nlatent+1));
-          discreteDRIFT[nlatent+1,nlatent+1] = 1;
-          etacov = quad_form(etacov, J\');
-          etacov[1:nlatent,1:nlatent] += sDIFFUSION;
-          if(intoverstates==0) discreteDIFFUSION = cholesky_decompose(makesym(discreteDIFFUSION,verbose,1));
-          eta[1:nlatent] = (discreteDRIFT * append_row(eta[1:nlatent],1.0))[1:nlatent];
         }
       } // end of non t0 time update
   
@@ -260,7 +247,7 @@ ukfilterfunc<-function(ppchecking){
   
       if(T0check[rowi]==1) {
         if(intoverpop==1) sigpoints[(nlatent+1):(nlatentpop), (nlatent+1):(nlatentpop)] = rawpopcovsqrt * sqrtukfadjust;
-        sigpoints[1:nlatent,1:nlatent] = sT0VAR * sqrtukfadjust;
+        sigpoints[1:nlatent,1:nlatent] = cholesky_decompose(sT0VAR) * sqrtukfadjust;
       }
       
       if(T0check[rowi]==0)  sigpoints = cholesky_decompose(makesym(etacov,verbose,1)) * sqrtukfadjust;
@@ -325,7 +312,7 @@ if(verbose > 1) print("etaprior = ", eta, " etapriorcov = ",etacov);
         if(intoverstates==0) { //sampled states
           if(ncont_y[rowi] > 0) {
             ypred[o0] = sMANIFESTMEANS[o0,1] + sLAMBDA[o0,] * eta[1:nlatent];
-            ypredcov_sqrt[o0,o0] = sMANIFESTVAR[o0,o0];
+            ypredcov_sqrt[o0,o0] = sqrt(sMANIFESTVAR[o0,o0]);
           }
           if(nbinary_y[rowi] > 0) ypred[o1] = to_vector(inv_logit(to_array_1d(sMANIFESTMEANS[o1,1] +sLAMBDA[o1,] * eta[1:nlatent])));
         }
@@ -338,17 +325,17 @@ if(verbose > 1) print("etaprior = ", eta, " etapriorcov = ",etacov);
 
         for(statei in 2:cols(ukfmeasures)){
           state = ukfstates[, statei];
-          ',paste0(ctstanmodel$calcs$dynamic,';\n',collapse=''),'
+          ',paste0(ctstanmodel$calcs$measurement,';\n',collapse=''),'
   
           ukfmeasures[, statei] = sMANIFESTMEANS[,1] + sLAMBDA * state[1:nlatent];
           if(nbinary_y[rowi] > 0) {
             ukfmeasures[o1 , statei] = to_vector(inv_logit(to_array_1d(ukfmeasures[o1 , statei])));
           }
         
-        merrorstates[,statei] = diagonal(sMANIFESTVAR);
+        merrorstates[,statei] = sqrt(diagonal(sMANIFESTVAR));
         for(wi in 1:nmanifest){ 
-          if(manifesttype[wi]==1 && Y[rowi,wi] != 99999) merrorstates[wi,statei] = sMANIFESTVAR[wi,wi] + fabs((ukfmeasures[wi,statei] - 1) .* (ukfmeasures[wi,statei])); //sMANIFESTVAR[wi,wi] + (merror[wi] / cols(ukfmeasures) +1e-8);
-          if(manifesttype[wi]==2 && Y[rowi,wi] != 99999) merrorstates[wi,statei] = sMANIFESTVAR[wi,wi] + square(fabs((ukfmeasures[wi,statei]- round(ukfmeasures[wi,statei])))); 
+          if(manifesttype[wi]==1 && Y[rowi,wi] != 99999) merrorstates[wi,statei] += fabs((ukfmeasures[wi,statei] - 1) .* (ukfmeasures[wi,statei])); 
+          if(manifesttype[wi]==2 && Y[rowi,wi] != 99999) merrorstates[wi,statei] += square(fabs((ukfmeasures[wi,statei]- round(ukfmeasures[wi,statei])))); 
         }
           
           if(statei==2 && ukffull == 1) { 
@@ -440,9 +427,11 @@ if(verbose > 2) print("ukfstates ", ukfstates, "  ukfmeasures ", ukfmeasures);
     }//end nobs > 0 section
   if(savescores==1) kout[rowi,(nmanifest*4+nlatentpop+1):(nmanifest*4+nlatentpop+nlatentpop)] = eta;','
 }//end rowi
-')}
+')
+if(!is.null(ctstanmodel$w32)) out <- ''
+return(out)}
 
-  kalmanll <- function(){'
+  kalmanll <- function(){ out <-'
   if(sum(nbinary_y) > 0) {
     vector[sum(nbinary_y)] binaryll;
     counter = 1;
@@ -467,51 +456,57 @@ if(verbose > 2) print("ukfstates ", ukfstates, "  ukfmeasures ", ukfmeasures);
     ll += normal_lpdf(errtrans[1]|0,1) - sum(errtrans[2]);
   }
 if(savescores) kalman = kout;
-'}
+'
+  if(!is.null(ctstanmodel$w32)) out <- ''
+  return(out)}
 
 
-subjectparaminit<- function(pop=FALSE,smats=TRUE){
-  if(smats && pop) stop('smats and pop cannot both be TRUE!')
+subjectparaminit<- function(popmats=FALSE,smats=TRUE){
+  if(smats && popmats) stop('smats and popmats cannot both be TRUE!')
   paste0(
    paste0( unlist(lapply(mats$base,function(m){
       paste0('matrix[ ',m,'setup_rowcount ? max(',m,'setup[,1]) : 0, ',m,'setup_rowcount ? max(',m,'setup[,2]) : 0 ] ',
-        ifelse(smats,'s',''),ifelse(pop,'pop_',''),m,if(!smats && !pop) paste0('[',m,'subindex[nsubjects]]'),';',collapse='\n')
+        ifelse(smats,'s',''),ifelse(popmats,'pop_',''),m,if(!smats && !popmats) paste0('[',m,'subindex[nsubjects]]'),';',collapse='\n')
     })),collapse='\n'),'
 
-  matrix[nlatent,nlatent] ',ifelse(smats,'s',''),ifelse(pop,'pop_',''),'asymDIFFUSION',if(!smats && !pop) '[asymDIFFUSIONsubindex[nsubjects]]','; //stationary latent process variance
-  vector[nt0meansstationary ? nlatent : 0] ',ifelse(smats,'s',''),ifelse(pop,'pop_',''),'asymCINT',if(!smats && !pop) '[asymCINTsubindex[nsubjects]]','; // latent process asymptotic level
+  matrix[nlatent,nlatent] ',ifelse(smats,'s',''),ifelse(popmats,'pop_',''),'asymDIFFUSION',if(!smats && !popmats) '[asymDIFFUSIONsubindex[nsubjects]]','; //stationary latent process variance
+  vector[nt0meansstationary ? nlatent : 0] ',ifelse(smats,'s',''),ifelse(popmats,'pop_',''),'asymCINT',if(!smats && !popmats) '[asymCINTsubindex[nsubjects]]','; // latent process asymptotic level
+',ifelse(smats,'matrix[nlatent, nlatent] sDIFFUSIONsqrt;',''),'
   ',collapse='\n')
 }
 
 
-subjectparscalc2 <- function(pop=FALSE,smats=TRUE){
+subjectparscalc2 <- function(popmats=FALSE,subjmats=TRUE){
   out <- paste0(
- '{
+ 'for(subi in (1-rowi ? si : 0):si){
   vector[nparams] rawindparams;
   vector[nparams] tipredaddition;
   vector[nparams] indvaraddition;
-  int output = ',as.integer(smats==FALSE && pop==TRUE),';
   
-  if(si < 2 || (si > 1 && (nindvarying >0 || ntipred > 0))){ //si of 0 used
+  if(subi < 2 || (subi > 1 && (nindvarying >0 || ntipred > 0))){ //subi of 0 used
     tipredaddition = rep_vector(0,nparams);
     indvaraddition = rep_vector(0,nparams);
 
-    if(si > 0 && nindvarying > 0 && intoverpop==0) indvaraddition[indvaryingindex] = rawpopcovsqrt * baseindparams[(1+(si-1)*nindvarying):(si*nindvarying)];
+    if(subi > 0 && nindvarying > 0 && intoverpop==0) {
+      if(fixedsubpars==0) indvaraddition[indvaryingindex] = rawpopcovsqrt * baseindparams[subi];
+      if(fixedsubpars==1) indvaraddition[indvaryingindex] = rawpopcovsqrt * fixedindparams[subi];
+    }
   
-    if(si > 0 &&  ntipred > 0) tipredaddition = TIPREDEFFECT * tipreds[si]\';
+    if(subi > 0 &&  ntipred > 0) tipredaddition = TIPREDEFFECT * tipreds[subi]\';
   
     rawindparams = rawpopmeans + tipredaddition + indvaraddition;
+
   }
 ',
 
     paste0(unlist(lapply(mats$base, function(m) {
       paste0('
-  if(si <= ',m,'subindex[nsubjects]){
+  if(subi <= ',m,'subindex[nsubjects]){
     for(ri in 1:size(',m,'setup)){
-      if(',m,'setup[ ri,5] > 0 || ',m,'setup[ ri,6] > 0 || si < 2){
+      if(',m,'setup[ ri,5] > 0 || ',m,'setup[ ri,6] > 0 || subi < 2){
         s',m,'[',m,'setup[ ri,1], ',m,'setup[ri,2]] = ',
           m,'setup[ri,3] ? ', 
-            'tform(rawindparams[ ',m,'setup[ri,3] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4] ) : ',
+            'tform(rawindparams[ ',m,'setup[ri,3] ], ',m,'setup[ri,4], ',m,'values[ri,2], ',m,'values[ri,3], ',m,'values[ri,4], ',m,'values[ri,6] ) : ',
             m,'values[ri,1]; //either transformed, scaled and offset free par, or fixed value
       }
     }
@@ -521,67 +516,54 @@ subjectparscalc2 <- function(pop=FALSE,smats=TRUE){
 
   // perform any whole matrix transformations 
     
-
-  if(si <= DIFFUSIONsubindex[nsubjects] &&(output==1|| ukf==0)) sDIFFUSION = sdcovsqrt2cov(sDIFFUSION,ukf);
-  if(ukf==0 || output ==1 || nt0varstationary > 0){
-    if(si <= asymDIFFUSIONsubindex[nsubjects]) {
+  
+  if(subi <= DIFFUSIONsubindex[nsubjects]) {
+    if(ukf==1) sDIFFUSIONsqrt = sDIFFUSION;
+    sDIFFUSION = sdcovsqrt2cov(sDIFFUSION,ukf);
+  }
+  if(subi <= asymDIFFUSIONsubindex[nsubjects]) {
       if(ndiffusion < nlatent) sasymDIFFUSION = to_matrix(rep_vector(0,nlatent * nlatent),nlatent,nlatent);
 
       if(continuoustime==1) sasymDIFFUSION[ derrind, derrind] = to_matrix( 
       -kronsum(sDRIFT[ derrind, derrind ]) \\  to_vector( 
-          ( (output==0 && ukf==1) ? tcrossprod(sDIFFUSION[ derrind, derrind ]) : sDIFFUSION[ derrind, derrind ] ) + 
-          IIlatent[ derrind, derrind ] * 1e-5), ndiffusion,ndiffusion);
+           sDIFFUSION[ derrind, derrind ]), ndiffusion,ndiffusion);
 
       if(continuoustime==0) sasymDIFFUSION = to_matrix( (IIlatent2 - 
-        sqkron_prod(sDRIFT, sDRIFT)) *  to_vector(
-          (output==0 && ukf==1) ? tcrossprod(sDIFFUSION[ derrind, derrind ]) : sDIFFUSION[ derrind, derrind ])
-        ,ndiffusion, ndiffusion);
+        sqkron_prod(sDRIFT, sDRIFT)) *  to_vector(sDIFFUSION[ derrind, derrind ]), ndiffusion, ndiffusion);
     } //end asymdiffusion loops
-  }
-          
-    if(nt0meansstationary > 0){
-      if(si <= asymCINTsubindex[nsubjects]){
-        if(continuoustime==1) sasymCINT =  -sDRIFT \\ sCINT[ ,1 ];
-        if(continuoustime==0) sasymCINT =  (IIlatent - sDRIFT) \\ sCINT[,1 ];
-      }
-    }
 
-          
-    if(binomial==0){
-      if(si <= MANIFESTVARsubindex[nsubjects]) {
+      if(subi <= MANIFESTVARsubindex[nsubjects]) {
          for(ri in 1:nmanifest) sMANIFESTVAR[ri,ri] = square(sMANIFESTVAR[ri,ri]);
       }
-    }
-          
-          
-    if(si <= T0VARsubindex[nsubjects]) {
-      if(ukf==0 || output==1) sT0VAR = sdcovsqrt2cov(sT0VAR,ukf);
+         
+    if(subi <= T0VARsubindex[nsubjects]) {
+      sT0VAR = makesym(sdcovsqrt2cov(sT0VAR,ukf),verbose,1);
       if(nt0varstationary > 0) {
-        if(ukf==1 && output ==0) sasymDIFFUSION = cholesky_decompose(makesym(sasymDIFFUSION,verbose,0));
-          for(ri in 1:nt0varstationary){ // in case of negative variances
-          sT0VAR[t0varstationary[ri,1],t0varstationary[ri,2] ] = 
-           t0varstationary[ri,1] == t0varstationary[ri,2] ? 
-            sqrt(square(sasymDIFFUSION[t0varstationary[ri,1],t0varstationary[ri,2] ])) : 
-            sasymDIFFUSION[t0varstationary[ri,1],t0varstationary[ri,2] ];
+        for(ri in 1:nt0varstationary){ 
+          sT0VAR[t0varstationary[ri,1],t0varstationary[ri,2] ] =  sasymDIFFUSION[t0varstationary[ri,1],t0varstationary[ri,2] ];
         }
       }
     }
     
     if(nt0meansstationary > 0){
-      if(si <= T0MEANSsubindex[nsubjects]) {
+      if(subi <= asymCINTsubindex[nsubjects]){
+        if(continuoustime==1) sasymCINT =  -sDRIFT \\ sCINT[ ,1 ];
+        if(continuoustime==0) sasymCINT =  (IIlatent - sDRIFT) \\ sCINT[,1 ];
+      }
+      if(subi <= T0MEANSsubindex[nsubjects]) {
         for(ri in 1:nt0meansstationary){
           sT0MEANS[t0meansstationary[ri,1] , 1] = 
             sasymCINT[t0meansstationary[ri,1] ];
         }
       }
     }
-  ',if(!smats) paste0('
-  if(si > 0){
-',collectsubmats(pop=FALSE),'
+  ',if(subjmats) paste0('
+  if(subi > 0){
+',collectsubmats(popmats=FALSE),'
   }',collapse=''),'
-',if(pop) paste0('
-  if(si == 0){
-',collectsubmats(pop=TRUE),'
+',if(popmats) paste0('
+  if(subi == 0){
+',collectsubmats(popmats=TRUE),'
   }
 ',collapse=''),'
 }
@@ -590,11 +572,11 @@ subjectparscalc2 <- function(pop=FALSE,smats=TRUE){
   return(out)
 }
 
-collectsubmats <- function(pop=FALSE,matrices=c(mats$base,'asymDIFFUSION','asymCINT')){
+collectsubmats <- function(popmats=FALSE,matrices=c(mats$base,'asymDIFFUSION','asymCINT')){
   out<-''
   for(m in matrices){
-    if(!pop) out <- paste0(out, m,'[',m,'subindex[si]] = s',m,'; \n')
-    if(pop) out <- paste0(out, 'pop_',m,' = s',m,'; \n')
+    if(!popmats) out <- paste0(out, m,'[',m,'subindex[subi]] = s',m,'; \n')
+    if(popmats) out <- paste0(out, 'pop_',m,' = s',m,'; \n')
   }
   return(out)
 }
@@ -606,35 +588,13 @@ collectsubmats <- function(pop=FALSE,matrices=c(mats$base,'asymDIFFUSION','asymC
   writemodel<-function(){
     paste0('
 functions{
-
-   matrix covsqrt2corsqrt(matrix mat, int invert){ //converts from unconstrained lower tri matrix to cor
-    matrix[rows(mat),cols(mat)] o;
-    vector[rows(mat)] s;
-  
-    for(i in 1:rows(o)){ //set upper tri to lower
-      for(j in min(i+1,rows(mat)):rows(mat)){
-        o[j,i] = inv_logit(mat[j,i])*2-1;  // can change cor prior here
-        o[i,j] = o[j,i];
-      }
-      o[i,i]=1; // change to adjust prior for correlations
-    }
-  
-    if(invert==1) o = inverse(o);
-  
-    for(i in 1:rows(o)){
-      s[i] = inv_sqrt(o[i,] * o[,i]);
-      if(is_inf(s[i])) s[i]=0;
-    }
-    return diag_pre_multiply(s,o);
-  }
-
-  int[] checkoffdiagzero(matrix M){
+ int[] checkoffdiagzero(matrix M){
     int z[rows(M)];
     for(i in 1:rows(M)){
       z[i] = 0;
       for(j in 1:cols(M)){
         if(i!=j){
-          if(M[i,j] != 0){
+          if(M[i,j] != 0.0){
             z[i] = 1;
             break;
           }
@@ -643,7 +603,7 @@ functions{
       if(z[i]==0){ //check rows
         for(j in 1:rows(M)){
           if(i!=j){
-            if(M[j,i] != 0){
+            if(M[j,i] != 0.0){
               z[i] = 1;
               break;
             }
@@ -677,24 +637,40 @@ functions{
     for(i in 1:size(z0)) out[z0[i],z0[i]] = exp(M[z0[i],z0[i]]);
     return out;
   }
-      
-  matrix sdcovsqrt2cov(matrix mat, int cholbasis){ //converts from lower partial sd and diag sd to cov or cholesky cov
+
+   matrix constraincorsqrt(matrix mat){ //converts from unconstrained lower tri matrix to cor
+    matrix[rows(mat),cols(mat)] o;
+    vector[rows(mat)] s;
+  
+    for(i in 1:rows(o)){ //set upper tri to lower
+      for(j in min(i+1,rows(mat)):rows(mat)){
+        o[j,i] =  inv_logit(mat[j,i])*2-1;  // can change cor prior here
+        o[i,j] = o[j,i];
+      }
+      o[i,i]=1; // change to adjust prior for correlations
+    }
+
+    for(i in 1:rows(o)){
+      s[i] = inv_sqrt(o[i,] * o[,i]);
+      if(is_inf(s[i])) s[i]=0;
+    }
+    return diag_pre_multiply(s,o);
+  } 
+
+  matrix sdcovsqrt2cov(matrix mat, int cholbasis){ //covariance from cholesky or unconstrained cor sq root
     if(cholbasis==0)  {
-      return(tcrossprod(diag_pre_multiply(diagonal(mat),covsqrt2corsqrt(mat, 0))));
+      return(tcrossprod(diag_pre_multiply(diagonal(mat),constraincorsqrt(mat))));
     } else return(tcrossprod(mat));
   }
 
   matrix sqkron_prod(matrix mata, matrix matb){
-    int m=rows(mata);
-    int p=rows(matb);
-    int n=cols(mata);
-    int q=cols(matb);
+    int d=rows(mata);
     matrix[rows(mata)*rows(matb),cols(mata)*cols(matb)] out;
-    for (k in 1:p){
-      for (l in 1:q){
-        for (i in 1:m){
-          for (j in 1:n){
-            out[ p*(i-1)+k, q*(j-1)+l ] = mata[i, j] * matb[k, l];
+    for (k in 1:d){
+      for (l in 1:d){
+        for (i in 1:d){
+          for (j in 1:d){
+            out[ d*(i-1)+k, d*(j-1)+l ] = mata[i, j] * matb[k, l];
           }
         }
       }
@@ -739,32 +715,33 @@ functions{
     return out;
   }
 
+
   matrix makesym(matrix mat, int verbose, int pd){
     matrix[rows(mat),cols(mat)] out;
     for(coli in 1:cols(mat)){
-      if(pd ==1 && mat[coli,coli] < 1e-5){
-        if(verbose > 0) print("diagonal too low (",mat[coli,coli],") during makesym row ", coli, " col ", coli);
-        out[coli,coli] = 1e-5;
+      if(pd ==1){ // && mat[coli,coli] < 1e-5
+        //if(verbose > 0) print("diagonal too low (",mat[coli,coli],") during makesym row ", coli, " col ", coli);
+        out[coli,coli] = mat[coli,coli] + 1e-5;
       } else out[coli,coli] = mat[coli,coli]; 
       for(rowi in coli:rows(mat)){
         if(rowi > coli) {
           out[rowi,coli] = mat[rowi,coli]; //(mat[coli,rowi] + ) *.5;
           out[coli,rowi] = mat[rowi,coli];
         }
-        if(is_nan(out[rowi,coli])){
+        ',if(gendata) paste0('if(is_nan(out[rowi,coli])){
           if(verbose > 0) print("nan during makesym row ", rowi, " col ", coli);
           if(rowi==coli) out[rowi,coli] = 99999;
           if(rowi!=coli) {
             out[rowi,coli] = 0;
             out[coli,rowi] = 0;
           }
-        }
+        }'),'
       }
     }
     return out;
   }
 
-  real tform(real param, int transform, data real multiplier, data real meanscale, data real offset){
+  real tform(real param, int transform, data real multiplier, data real meanscale, data real offset, data real inneroffset){
     real out;
   
     ',tformshapes(),
@@ -796,7 +773,6 @@ data {
   
   real dT[ndatapoints]; // time intervals
   real dTsmall[ndatapoints];
-  int binomial; //binary data only
   int integrationsteps[ndatapoints] ; // time steps needed between time intervals for integration
   int subject[ndatapoints];
   int<lower=0> nparams;
@@ -805,6 +781,7 @@ data {
   int nindvaryingoffdiagonals; //number of off diagonal parameters needed for popcov matrix
   vector[nindvarying] sdscale;
   int indvaryingindex[nindvarying];
+  int notindvaryingindex[nparams-nindvarying];
 
   int nt0varstationary;
   int nt0meansstationary;
@@ -833,35 +810,31 @@ data {
   ',paste0(unlist(lapply(c(mats$base,'asymCINT','asymDIFFUSION'),function(mati) paste0('int ',mati,'subindex[nsubjects];',collapse='\n'))),collapse='\n'),'
   ',paste0(unlist(lapply(mats$base,function(m) paste0('int ',m,'setup_rowcount;',collapse='\n'))),collapse='\n'),'
   ',paste0(unlist(lapply(mats$base,function(m) paste0('int ',m,'setup[',m,'setup_rowcount,6 ];',collapse='\n'))),collapse='\n'),'
-  ',paste0(unlist(lapply(mats$base,function(m) paste0('matrix[',m,'setup_rowcount, 5] ',m,'values;'))),collapse='\n'),'
+  ',paste0(unlist(lapply(mats$base,function(m) paste0('matrix[',m,'setup_rowcount, 6] ',m,'values;'))),collapse='\n'),'
   int TIPREDEFFECTsetup[nparams, ntipred];
   int nmatrixslots;
   int popsetup[nmatrixslots,6];
-  real popvalues[nmatrixslots,5];
+  real popvalues[nmatrixslots,6];
   int savescores;
+  int nlatentpop;
+  int fixedsubpars;
+  vector[fixedsubpars ? nindvarying : 0] fixedindparams[fixedsubpars ? nsubjects : 0];
+  int dokalman;
 }
       
 transformed data{
-  matrix[nlatent,nlatent] IIlatent;
-  matrix[nlatent*nlatent,nlatent*nlatent] IIlatent2;
-  int nlatentpop;
-  real asquared;
-  real sqrtukfadjust;
-  nlatentpop = intoverpop ? nlatent + nindvarying : nlatent;
-  IIlatent = diag_matrix(rep_vector(1,nlatent));
-  IIlatent2 = diag_matrix(rep_vector(1,nlatent*nlatent));
-
-  //ukf approximation parameters
-  asquared =  square(2.0/sqrt(0.0+nlatentpop) * ukfspread); 
-  sqrtukfadjust = sqrt(0.0+nlatentpop +( asquared * (nlatentpop  + 0.5) - (nlatentpop) ) );
+  matrix[nlatent,nlatent] IIlatent= diag_matrix(rep_vector(1,nlatent));
+  matrix[nlatent*nlatent,nlatent*nlatent] IIlatent2 = diag_matrix(rep_vector(1,nlatent*nlatent));
+  matrix[nindvarying,nindvarying] IIindvar = diag_matrix(rep_vector(1,nindvarying));
+  real asquared =  square(2.0/sqrt(0.0+nlatentpop) * ukfspread);
+  real sqrtukfadjust = sqrt(0.0+nlatentpop +( asquared * (nlatentpop  + 0.5) - (nlatentpop) ) );
 }
       
 parameters {
   vector[nparams] rawpopmeans; // population level means \n','
-  vector',if(!is.na(ctstanmodel$rawpopsdbaselowerbound)) paste0('<lower=',ctstanmodel$rawpopsdbaselowerbound[1],'>'),'[nindvarying ? 1 : 0] rawpopsdbase; //population level std dev
-  simplex[nindvarying] rawpopsdprops[nindvarying ? 1 : 0];
+  vector',if(!is.na(ctstanmodel$rawpopsdbaselowerbound)) paste0('<lower=',ctstanmodel$rawpopsdbaselowerbound[1],'>'),'[nindvarying] rawpopsdbase; //population level std dev
   vector[nindvaryingoffdiagonals] sqrtpcov; // unconstrained basis of correlation parameters
-  vector[intoverpop ? 0 : nindvarying*nsubjects] baseindparams; //vector of subject level deviations, on the raw scale
+  vector[fixedsubpars ? 0 : (intoverpop ? 0 : nindvarying)] baseindparams[fixedsubpars ? 0 : (intoverpop ? 0 : nsubjects)]; //vector of subject level deviations, on the raw scale
   
   vector[ntipredeffects] tipredeffectparams; // effects of time independent covariates
   vector[nmissingtipreds] tipredsimputed;
@@ -874,6 +847,8 @@ transformed parameters{
   matrix[nindvarying,nindvarying] rawpopcovsqrt; 
   real ll;
   vector[nmanifest+nmanifest+ (savescores ? nmanifest*2+nlatentpop*2 : 0)] kalman[savescores ? ndatapoints : 0];
+  ',subjectparaminit(pop=FALSE,smats=FALSE),'
+  ',subjectparaminit(pop=TRUE,smats=FALSE),'
 
   matrix[ntipred ? nsubjects : 0, ntipred ? ntipred : 0] tipreds; //tipred values to fill from data and, when needed, imputation vector
   matrix[nparams, ntipred] TIPREDEFFECT; //design matrix of individual time independent predictor effects
@@ -901,7 +876,7 @@ transformed parameters{
 
   if(nindvarying > 0){
     int counter =0;
-    rawpopsd = sqrt(rawpopsdprops[1] * square(',ctstanmodel$rawpopsdtransform, ')[1]) .*sdscale; // sqrts of proportions of total variance
+    rawpopsd = ',ctstanmodel$rawpopsdtransform, '; // sqrts of proportions of total variance
     for(j in 1:nindvarying){
       rawpopcovsqrt[j,j] = 1;
       for(i in 1:nindvarying){
@@ -912,12 +887,12 @@ transformed parameters{
         }
       }
     }
-    rawpopcovsqrt = diag_pre_multiply(rawpopsd, 
-      covsqrt2corsqrt(rawpopcovsqrt,0)); 
+ rawpopcovsqrt = cholesky_decompose(makesym(tcrossprod(diag_pre_multiply(rawpopsd, 
+      constraincorsqrt(rawpopcovsqrt))),verbose,1)); 
   }//end indvarying par setup
 
   ll=0;
-{',
+if(dokalman==1){',
 if(!gendata) ukfilterfunc(ppchecking=FALSE),
 if(!gendata) kalmanll(),'
 }
@@ -926,8 +901,10 @@ if(!gendata) kalmanll(),'
       
 model{
 
+  if(intoverpop==0 && fixedsubpars == 1) fixedindparams ~ multi_normal_cholesky(rep_vector(0,nindvarying),IIindvar);
+
   if(nopriors==0){
-    target += normal_lpdf(rawpopmeans|0,1);
+   target += normal_lpdf(rawpopmeans|0,1);
   
     if(ntipred > 0){ 
       tipredeffectparams ~ normal(0,tipredeffectscale);
@@ -936,7 +913,7 @@ model{
     
     if(nindvarying > 0){
       if(nindvarying >1) sqrtpcov ~ normal(0,1);
-      if(intoverpop==0) baseindparams ~ normal(0,1);
+      if(intoverpop==0 && fixedsubpars == 0) baseindparams ~ multi_normal_cholesky(rep_vector(0,nindvarying),IIindvar);
       rawpopsdbase ~ ',ctstanmodel$rawpopsdbase,';
     }
   } //end pop priors section
@@ -948,42 +925,26 @@ model{
 }
 generated quantities{
   vector[nparams] popmeans;
-  vector[nparams] popsd;
-  matrix[nindvarying,nindvarying] rawpopcov;
-  matrix[nindvarying,nindvarying] rawpopcorr;
+  vector[nparams] popsd = rep_vector(0,nparams);
+  matrix[nindvarying,nindvarying] rawpopcov = tcrossprod(rawpopcovsqrt);
+  matrix[nindvarying,nindvarying] rawpopcorr = quad_form_diag(rawpopcov,inv_sqrt(diagonal(rawpopcov)));
   matrix[nparams,ntipred] linearTIPREDEFFECT;
   ',if(gendata) 'vector[nmanifest] Ygen[ndatapoints];','
 
-  ',subjectparaminit(pop=TRUE,smats=FALSE),'
-
-  ',subjectparaminit(pop=FALSE,smats=FALSE),'
-
-  {
-  ',subjectparaminit(pop=FALSE,smats=TRUE),'
-
-  for(si in 0:subject[ndatapoints]){
-    ',subjectparscalc2(pop=TRUE,smats=FALSE),'
-    }
-  }
-
-rawpopcov = tcrossprod(rawpopcovsqrt);
-rawpopcorr = quad_form_diag(rawpopcov,inv_sqrt(diagonal(rawpopcov)));
-
-popsd = rep_vector(0,nparams);
 {
 vector[nparams] rawpopsdfull;
-rawpopsdfull[indvaryingindex] = rawpopsd; //base for calculations
+rawpopsdfull[indvaryingindex] = sqrt(diagonal(rawpopcov)); //base for calculations
 
     for(ri in 1:dims(popsetup)[1]){
       if(popsetup[ri,3] !=0) {
 
-        popmeans[popsetup[ ri,3]] = tform(rawpopmeans[popsetup[ri,3] ], popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4] ); 
+        popmeans[popsetup[ ri,3]] = tform(rawpopmeans[popsetup[ri,3] ], popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4], popvalues[ri,6] ); 
 
         popsd[popsetup[ ri,3]] = popsetup[ ri,5] ? 
           fabs(tform(
-            rawpopmeans[popsetup[ri,3] ]  + rawpopsdfull[popsetup[ ri,3]], popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4]) -
+            rawpopmeans[popsetup[ri,3] ]  + rawpopsdfull[popsetup[ ri,3]], popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4], popvalues[ri,6]) -
            tform(
-            rawpopmeans[popsetup[ri,3] ]  - rawpopsdfull[popsetup[ ri,3]], popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4]) ) /2 : 
+            rawpopmeans[popsetup[ri,3] ]  - rawpopsdfull[popsetup[ ri,3]], popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4], popvalues[ri,6]) ) /2 : 
           0; 
 
         if(ntipred > 0){
@@ -992,8 +953,8 @@ rawpopsdfull[indvaryingindex] = rawpopsd; //base for calculations
               linearTIPREDEFFECT[popsetup[ri,3],tij] = 0;
             } else {
             linearTIPREDEFFECT[popsetup[ri,3],tij] = (
-              tform(rawpopmeans[popsetup[ri,3] ] + TIPREDEFFECT[popsetup[ri,3],tij] * .01, popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4] ) -
-              tform(rawpopmeans[popsetup[ri,3] ] - TIPREDEFFECT[popsetup[ri,3],tij] * .01, popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4] )
+              tform(rawpopmeans[popsetup[ri,3] ] + TIPREDEFFECT[popsetup[ri,3],tij] * .01, popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4], popvalues[ri,6] ) -
+              tform(rawpopmeans[popsetup[ri,3] ] - TIPREDEFFECT[popsetup[ri,3],tij] * .01, popsetup[ri,4], popvalues[ri,2], popvalues[ri,3], popvalues[ri,4], popvalues[ri,6] )
               ) /2 * 100;
             }
          }
